rnalab_scatterplot: Plot Scatterplots for input data

Description Usage Arguments Value Examples

View source: R/plot.r

Description

Use ggplot2 to generate Scatterplots for input data. Allows the option to plot a linear regression fit.

Usage

1

Arguments

data

Dataset to use for ggplot2 plots

x, y

The x and y variables to be used in the aes() mapping for ggplot scatterplots

fit

A boolean indicating whether a linear regression fit should be added to the ggplot scatterplot

Value

A grid graphical object consisting of a ggplot2 jitter plot with or without a linear regression fit.

Examples

1
2
3
4
# Plot a scatter plot without linear regression added (using data from the dnaseqs data set)
rnalab_scatterplot(dnaseqs, x = 'length', y = 'yield', fit = FALSE)
# Plot a scatter plot with linear regression added (using data from the dnaseqs data set)
rnalab_scatterplot(dnaseqs, x = 'length', y = 'yield', fit = TRUE)

batra-akshita/rnalab documentation built on March 24, 2020, 12:03 a.m.