Description Usage Arguments Value Examples
Use ggplot2 to generate Scatterplots for input data. Allows the option to plot a linear regression fit.
1 | rnalab_scatterplot(data, x, y, fit)
|
data |
Dataset to use for ggplot2 plots |
x, y |
The x and y variables to be used in the aes() mapping for ggplot scatterplots |
fit |
A boolean indicating whether a linear regression fit should be added to the ggplot scatterplot |
A grid graphical object consisting of a ggplot2 jitter plot with or without a linear regression fit.
1 2 3 4 | # Plot a scatter plot without linear regression added (using data from the dnaseqs data set)
rnalab_scatterplot(dnaseqs, x = 'length', y = 'yield', fit = FALSE)
# Plot a scatter plot with linear regression added (using data from the dnaseqs data set)
rnalab_scatterplot(dnaseqs, x = 'length', y = 'yield', fit = TRUE)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.